Crate lintel_schema_cache

Crate lintel_schema_cache 

Structs

ReqwestClient
Default HTTP client using reqwest.
SchemaCache
A disk-backed cache for JSON Schema files.

Enums

CacheStatus
Whether a schema was served from disk cache or fetched from the network.

Constants

DEFAULT_SCHEMA_CACHE_TTL
Default TTL for cached schemas (12 hours).

Traits

HttpClient
Trait for fetching content over HTTP.

Functions

ensure_cache_dir
Return a usable cache directory for schemas, creating it if necessary.